@@ -12,7 +12,7 @@ def jaccard(query):
     on a given iterable, taking the *query* into
     account.
 
-    :param query: The first iterable.
+    :param query: An initial query value.
     """
     query = set(query)
     length = len(query)
@@ -21,7 +21,7 @@ def jaccard(query):
         if not value:
             return 0.0
         value = set(value)
-        inter = sum(1 for a in query if a in value)
+        inter = len(query & value)
         union = len(value) + length - inter
         return inter / float(union)
     return rank
@@ -35,19 +35,17 @@ def relevance(query):
     the query all need to be present in a given
     choice, in the same order.
 
-    :param query: The first iterable.
+    :param query: An initial query value.
     """
     query_length = len(query)
 
     def rank(value):
         length = len(value)
-        if not length or length < query_length:
-            return 0.0
-        start = 0
-        for char in query:
-            idx = value.find(char, start)
-            if idx == -1:
-                return 0.0
-            start = idx + 1
-        return query_length / float(length)
+        if length >= query_length:
+            for char in query:
+                _, sep, value = value.partition(char)
+                if not sep:
+                    return 0.0
+            return query_length / float(length)
+        return 0.0
     return rank
